#' List of EVAS Codes
#'
#' @format ## `evas_list`
#' A data frame with 1132 rows and 3 columns:
#' \describe{
#'   \item{EVAS}{EVAS code}
#'   \item{Beschreibung}{Details on the EVAS code}
#'   \item{Titel}{Alternative desription of EVAS code contents}
#' }
#' @source <https://www.destatis.de/DE/Methoden/Revisionen/Glossar/EVAS.html>
"evas_list"
